@@ -26,7 +26,6 @@
 #include "panelpluginsmodel.h"
 #include "plugin.h"
 #include "ilxqtpanelplugin.h"
-#include "lxqtpanel.h"
 #include "lxqtpanelapplication.h"
 #include <QPointer>
 #include <XdgIcon>
@@ -35,14 +34,15 @@
 #include <QDebug>
 
 PanelPluginsModel::PanelPluginsModel(LXQtPanel * panel,
+                                     LXQt::Settings * settings,
                                      QString const & namesKey,
                                      QStringList const & desktopDirs,
                                      QObject * parent/* = nullptr*/)
     : QAbstractListModel{parent},
     mNamesKey(namesKey),
-    mPanel(panel)
+    mPanelSettings(settings)
 {
-    loadPlugins(desktopDirs);
+    loadPlugins(panel, desktopDirs);
 }
 
 PanelPluginsModel::~PanelPluginsModel()
@@ -86,9 +86,11 @@ QVariant PanelPluginsModel::data(const QModelIndex & index, int role/* = Qt::Dis
     return ret;
 }
 
-Qt::ItemFlags PanelPluginsModel::flags(const QModelIndex & /*index*/) const
+Qt::ItemFlags PanelPluginsModel::flags(const QModelIndex & index) const
 {
-    return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemNeverHasChildren;
+    if (!index.isValid())
+        return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemNeverHasChildren | Qt::ItemIsDropEnabled;
+    return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemNeverHasChildren | Qt::ItemIsDragEnabled;
 }
 
 QStringList PanelPluginsModel::pluginNames() const
@@ -127,21 +129,21 @@ Plugin const * PanelPluginsModel::pluginByID(QString id) const
     return nullptr;
 }
 
-void PanelPluginsModel::addPlugin(const LXQt::PluginInfo &desktopFile)
+void PanelPluginsModel::addPlugin(LXQtPanel * panel, const LXQt::PluginInfo &desktopFile)
 {
     if (dynamic_cast<LXQtPanelApplication const *>(qApp)->isPluginSingletonAndRunning(desktopFile.id()))
         return;
 
     QString name = findNewPluginSettingsGroup(desktopFile.id());
 
-    QPointer<Plugin> plugin = loadPlugin(desktopFile, name);
+    QPointer<Plugin> plugin = loadPlugin(panel, desktopFile, name);
     if (plugin.isNull())
         return;
 
     beginInsertRows(QModelIndex(), mPlugins.size(), mPlugins.size());
     mPlugins.append({name, plugin});
     endInsertRows();
-    mPanel->settings()->setValue(mNamesKey, pluginNames());
+    mPanelSettings->setValue(mNamesKey, pluginNames());
     emit pluginAdded(plugin.data());
 }
 
@@ -149,14 +151,14 @@ void PanelPluginsModel::removePlugin(pluginslist_t::iterator plugin)
 {
     if (mPlugins.end() != plugin)
     {
-        mPanel->settings()->remove(plugin->first);
+        mPanelSettings->remove(plugin->first);
         Plugin * p = plugin->second.data();
         const int row = plugin - mPlugins.begin();
         beginRemoveRows(QModelIndex(), row, row);
         mPlugins.erase(plugin);
         endRemoveRows();
         emit pluginRemoved(p); // p can be nullptr
-        mPanel->settings()->setValue(mNamesKey, pluginNames());
+        mPanelSettings->setValue(mNamesKey, pluginNames());
         if (nullptr != p)
             p->deleteLater();
     }
@@ -180,6 +182,16 @@ void PanelPluginsModel::movePlugin(Plugin * plugin, QString const & nameAfter)
     const int to =
         std::find_if(mPlugins.begin(), mPlugins.end(), [nameAfter] (pluginslist_t::const_reference obj) { return nameAfter == obj.first; })
         - mPlugins.begin();
+
+    if (from != movePlugin(from, to))
+        emit pluginMoved(plugin);
+}
+
+int PanelPluginsModel::movePlugin(const int from, int to)
+{
+    if (to > mPlugins.size())
+        to = mPlugins.size();
+
     /* 'from' is the current position of the Plugin to be moved ("moved Plugin"),
      * 'to' is the position of the Plugin behind the one that is being moved
      * ("behind Plugin"). There are several cases to distinguish:
@@ -210,14 +222,58 @@ void PanelPluginsModel::movePlugin(Plugin * plugin, QString const & nameAfter)
         // For the QList::move method, use the right position
         mPlugins.move(from, to_plugins);
         endMoveRows();
-        emit pluginMoved(plugin);
-        mPanel->settings()->setValue(mNamesKey, pluginNames());
+        mPanelSettings->setValue(mNamesKey, pluginNames());
+        return to_plugins;
     }
+
+    return from;
 }
 
-void PanelPluginsModel::loadPlugins(QStringList const & desktopDirs)
+Qt::DropActions PanelPluginsModel::supportedDropActions() const
 {
-    QStringList plugin_names = mPanel->settings()->value(mNamesKey).toStringList();
+    return Qt::MoveAction;
+}
+
+bool PanelPluginsModel::moveRows(const QModelIndex &sourceParent, int sourceRow, int count, const QModelIndex &destinationParent, int destinationChild) {
+    const auto sourceIndex = index(sourceRow);
+    if (sourceParent == destinationParent && count == 1 && sourceIndex.isValid() && destinationChild >= 0 && destinationChild <= mPlugins.size()) {
+        const auto dest = movePlugin(sourceRow, destinationChild);
+        if (sourceRow != dest)
+        {
+            pluginslist_t::const_reference moved_plugin = mPlugins[dest];
+            emit pluginMoved(moved_plugin.second);
+            if (!moved_plugin.second.isNull())
+            {
+                if (sourceRow < dest) {
+                    // moved downwards
+                    for (int row = sourceRow; row < dest; ++row)
+                    {
+                        pluginslist_t::const_reference after_plugin = mPlugins[row];
+                        //emit signal for layout only in case plugin is loaded/displayed
+                        if (!after_plugin.second.isNull())
+                            emit pluginMovedUp(after_plugin.second.data());
+                    }
+                } else
+                {
+                    // moved upwards
+                    for (int row = sourceRow; row > dest; --row)
+                    {
+                        pluginslist_t::const_reference before_plugin = mPlugins[row];
+                        //emit signal for layout only in case plugin is loaded/displayed
+                        if (!before_plugin.second.isNull())
+                            emit pluginMovedUp(moved_plugin.second.data());
+                    }
+                }
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+void PanelPluginsModel::loadPlugins(LXQtPanel * panel, QStringList const & desktopDirs)
+{
+    QStringList plugin_names = mPanelSettings->value(mNamesKey).toStringList();
 
 #ifdef DEBUG_PLUGIN_LOADTIME
     QElapsedTimer timer;
@@ -227,10 +283,10 @@ void PanelPluginsModel::loadPlugins(QStringList const & desktopDirs)
     for (auto const & name : std::as_const(plugin_names))
     {
         pluginslist_t::iterator i = mPlugins.insert(mPlugins.end(), {name, nullptr});
-        QString type = mPanel->settings()->value(name + QStringLiteral("/type")).toString();
+        QString type = mPanelSettings->value(name + QStringLiteral("/type")).toString();
         if (type.isEmpty())
         {
-            qWarning() << QStringLiteral("Section \"%1\" not found in %2.").arg(name, mPanel->settings()->fileName());
+            qWarning() << QStringLiteral("Section \"%1\" not found in %2.").arg(name, mPanelSettings->fileName());
             continue;
         }
 #ifdef WITH_SCREENSAVER_FALLBACK
@@ -241,15 +297,14 @@ void PanelPluginsModel::loadPlugins(QStringList const & desktopDirs)
             const QString & lock_desktop = QStringLiteral(LXQT_LOCK_DESKTOP);
             qWarning().noquote() << "Found deprecated plugin of type 'screensaver', migrating to 'quicklaunch' with '" << lock_desktop << '\'';
             type = QStringLiteral("quicklaunch");
-            LXQt::Settings * settings = mPanel->settings();
-            settings->beginGroup(name);
-            settings->remove(QString{});//remove all existing keys
-            settings->setValue(QStringLiteral("type"), type);
-            settings->beginWriteArray(QStringLiteral("apps"), 1);
-            settings->setArrayIndex(0);
-            settings->setValue(QStringLiteral("desktop"), lock_desktop);
-            settings->endArray();
-            settings->endGroup();
+            mPanelSettings->beginGroup(name);
+            mPanelSettings->remove(QString{});//remove all existing keys
+            mPanelSettings->setValue(QStringLiteral("type"), type);
+            mPanelSettings->beginWriteArray(QStringLiteral("apps"), 1);
+            mPanelSettings->setArrayIndex(0);
+            mPanelSettings->setValue(QStringLiteral("desktop"), lock_desktop);
+            mPanelSettings->endArray();
+            mPanelSettings->endGroup();
         }
 #endif
 
@@ -260,7 +315,7 @@ void PanelPluginsModel::loadPlugins(QStringList const & desktopDirs)
             continue;
         }
 
-        i->second = loadPlugin(list.first(), name);
+        i->second = loadPlugin(panel, list.first(), name);
 #ifdef DEBUG_PLUGIN_LOADTIME
         qDebug() << "load plugin" << type << "takes" << (timer.elapsed() - lastTime) << "ms";
         lastTime = timer.elapsed();
@@ -268,12 +323,11 @@ void PanelPluginsModel::loadPlugins(QStringList const & desktopDirs)
     }
 }
 
-QPointer<Plugin> PanelPluginsModel::loadPlugin(LXQt::PluginInfo const & desktopFile, QString const & settingsGroup)
+QPointer<Plugin> PanelPluginsModel::loadPlugin(LXQtPanel * panel, LXQt::PluginInfo const & desktopFile, QString const & settingsGroup)
 {
-    std::unique_ptr<Plugin> plugin(new Plugin(desktopFile, mPanel->settings(), settingsGroup, mPanel));
+    std::unique_ptr<Plugin> plugin(new Plugin(desktopFile, mPanelSettings, settingsGroup, panel));
     if (plugin->isLoaded())
     {
-        connect(mPanel, &LXQtPanel::realigned, plugin.get(), &Plugin::realign);
         connect(plugin.get(), &Plugin::remove,
                 this, static_cast<void (PanelPluginsModel::*)()>(&PanelPluginsModel::removePlugin));
         return plugin.release();
@@ -284,7 +338,7 @@ QPointer<Plugin> PanelPluginsModel::loadPlugin(LXQt::PluginInfo const & desktopF
 
 QString PanelPluginsModel::findNewPluginSettingsGroup(const QString &pluginType) const
 {
-    QStringList groups = mPanel->settings()->childGroups();
+    QStringList groups = mPanelSettings->childGroups();
     groups.sort();
 
     // Generate new section name
@@ -329,7 +383,7 @@ void PanelPluginsModel::onMovePluginUp(QModelIndex const & index)
     if (!moved_plugin.second.isNull() && !prev_plugin.second.isNull())
         emit pluginMovedUp(moved_plugin.second.data());
 
-    mPanel->settings()->setValue(mNamesKey, pluginNames());
+    mPanelSettings->setValue(mNamesKey, pluginNames());
 }
 
 void PanelPluginsModel::onMovePluginDown(QModelIndex const & index)
@@ -352,7 +406,7 @@ void PanelPluginsModel::onMovePluginDown(QModelIndex const & index)
     if (!moved_plugin.second.isNull() && !next_plugin.second.isNull())
         emit pluginMovedUp(next_plugin.second.data());
 
-    mPanel->settings()->setValue(mNamesKey, pluginNames());
+    mPanelSettings->setValue(mNamesKey, pluginNames());
 }
 
 void PanelPluginsModel::onConfigurePlugin(QModelIndex const & index)
