@@ -90,11 +90,11 @@ LXQtMainMenuConfiguration::LXQtMainMenuConfiguration(PluginSettings *settings, G
         if (!mLockSettingChanges)
             this->settings().setValue(QStringLiteral("filterShow"), value);
     });
-    connect(ui->filterShowMaxItemsSB, QOverload<int>::of(&QSpinBox::valueChanged), this, [this] (int value) {
+    connect(ui->filterShowMaxItemsSB, &QSpinBox::valueChanged, this, [this] (int value) {
         if (!mLockSettingChanges)
             this->settings().setValue(QStringLiteral("filterShowMaxItems"), value);
     });
-    connect(ui->filterShowMaxWidthSB, QOverload<int>::of(&QSpinBox::valueChanged), this, [this] (int value) {
+    connect(ui->filterShowMaxWidthSB, &QSpinBox::valueChanged, this, [this] (int value) {
         if (!mLockSettingChanges)
             this->settings().setValue(QStringLiteral("filterShowMaxWidth"), value);
     });
@@ -124,10 +124,11 @@ void LXQtMainMenuConfiguration::loadSettings()
 
     QString menuFile = settings().value(QStringLiteral("menu_file"), QString()).toString();
     if (menuFile.isEmpty())
-    {
         menuFile = XdgMenu::getMenuFileName();
-    }
+    else if (!menuFile.contains(QLatin1String("/")))
+        menuFile = XdgMenu::getMenuFileName(menuFile);
     ui->menuFilePathLE->setText(menuFile);
+
     ui->shortcutEd->setText(nullptr != mShortcut ? mShortcut->shortcut() : mDefaultShortcut);
 
     ui->customFontCB->setChecked(settings().value(QStringLiteral("customFont"), false).toBool());
