@@ -12,107 +12,107 @@
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="546"/>
+        <location filename="../lxqttaskbutton.cpp" line="547"/>
         <source>Application</source>
         <translation>Aplicació</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="580"/>
+        <location filename="../lxqttaskbutton.cpp" line="581"/>
         <source>To &amp;Desktop</source>
         <translation>A l&apos;&amp;escriptori</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="583"/>
+        <location filename="../lxqttaskbutton.cpp" line="584"/>
         <source>&amp;All Desktops</source>
         <translation>T&amp;ots els escriptoris</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="593"/>
+        <location filename="../lxqttaskbutton.cpp" line="594"/>
         <source>Desktop &amp;%1</source>
         <translation>Escriptori &amp;%1</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="603"/>
+        <location filename="../lxqttaskbutton.cpp" line="604"/>
         <source>&amp;To Current Desktop</source>
         <translation>A l&apos;escriptori ac&amp;tual</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="612"/>
+        <location filename="../lxqttaskbutton.cpp" line="616"/>
         <source>Move To N&amp;ext Monitor</source>
         <translation>Canvia al s&amp;egüent monitor</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="618"/>
+        <location filename="../lxqttaskbutton.cpp" line="619"/>
         <source>Move To &amp;Previous Monitor</source>
         <translation>Mou al &amp;monitor anterior</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="624"/>
+        <location filename="../lxqttaskbutton.cpp" line="625"/>
         <source>&amp;Move</source>
         <translation>&amp;Mou</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="629"/>
+        <location filename="../lxqttaskbutton.cpp" line="630"/>
         <source>Resi&amp;ze</source>
         <translation>Redimen&amp;siona</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="638"/>
+        <location filename="../lxqttaskbutton.cpp" line="639"/>
         <source>Ma&amp;ximize</source>
         <translation>Ma&amp;ximitza</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="647"/>
+        <location filename="../lxqttaskbutton.cpp" line="648"/>
         <source>Maximize vertically</source>
         <translation>Maximitza verticalment</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="654"/>
+        <location filename="../lxqttaskbutton.cpp" line="655"/>
         <source>Maximize horizontally</source>
         <translation>Maximitza horitzontalment</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="662"/>
+        <location filename="../lxqttaskbutton.cpp" line="663"/>
         <source>&amp;Restore</source>
         <translation>&amp;Restaura</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="670"/>
+        <location filename="../lxqttaskbutton.cpp" line="671"/>
         <source>Mi&amp;nimize</source>
         <translation>Mi&amp;nimitza</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="678"/>
+        <location filename="../lxqttaskbutton.cpp" line="679"/>
         <source>Roll down</source>
         <translation>Enrotlla cap avall</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="686"/>
+        <location filename="../lxqttaskbutton.cpp" line="687"/>
         <source>Roll up</source>
         <translation>Enrotlla cap amunt</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="695"/>
+        <location filename="../lxqttaskbutton.cpp" line="696"/>
         <source>&amp;Layer</source>
         <translation>&amp;Capa</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="700"/>
+        <location filename="../lxqttaskbutton.cpp" line="701"/>
         <source>Always on &amp;top</source>
         <translation>Sempre a la par&amp;t superior</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="705"/>
+        <location filename="../lxqttaskbutton.cpp" line="706"/>
         <source>&amp;Normal</source>
         <translation>&amp;Normal</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="710"/>
+        <location filename="../lxqttaskbutton.cpp" line="711"/>
         <source>Always on &amp;bottom</source>
         <translation>Sempre a la part in&amp;ferior</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="717"/>
+        <location filename="../lxqttaskbutton.cpp" line="718"/>
         <source>&amp;Close</source>
         <translation>Tan&amp;ca</translation>
     </message>
@@ -290,5 +290,10 @@
         <source>Current</source>
         <translation>Actual</translation>
     </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="67"/>
+        <source>Desktop %1</source>
+        <translation>Escriptori %1</translation>
+    </message>
 </context>
 </TS>
